=========
Education
=========

Jupyter Notebooks offer exciting and creative possibilities in education. The
following subprojects are focused on supporting the use of Jupyter Notebook in
a variety of educational settings.

`Teaching and Learning with Jupyter <https://jupyter4edu.github.io/jupyter-edu-book/>`__
is a book about using Jupyter in teaching and learning.

.. glossary::

    `nbgrader <https://nbgrader.readthedocs.io/en/stable/>`__
        tools for managing, grading, and reporting of notebook based
        assignments.
        `Documentation <https://nbgrader.readthedocs.io/en/stable/>`__ |
        `Repo <https://github.com/jupyter/nbgrader>`__

    `jupyter4edu <https://github.com/orgs/jupyter4edu/>`__
        GitHub organization hosting community resources for Jupyter in education
